# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from typing_extensions import Annotated
from pydantic import Field, StrictInt, StrictStr, constr, validator

from typing import Dict, List, Optional

from seaplane.gen.carrier.models.flow import Flow
from seaplane.gen.carrier.models.secret import Secret

from seaplane.gen.carrier.api_client import ApiClient
from seaplane.gen.carrier.api_response import ApiResponse
from seaplane.gen.carrier.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class FlowApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_flow(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        flow: Annotated[Optional[Flow], Field(description="Flow definition")] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Create a Flow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_flow(flow_name, region, flow, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param flow: Flow definition
        :type flow: Flow
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the create_flow_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.create_flow_with_http_info(
            flow_name, region, flow, **kwargs
        )  # noqa: E501

    @validate_arguments
    def create_flow_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        flow: Annotated[Optional[Flow], Field(description="Flow definition")] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Create a Flow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_flow_with_http_info(flow_name, region, flow, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param flow: Flow definition
        :type flow: Flow
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["flow_name", "region", "flow"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_flow" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["flow"] is not None:
            _body_params = _params["flow"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/flow/{flow_name}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_flow(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Delete a Flow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_flow(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the delete_flow_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.delete_flow_with_http_info(
            flow_name, region, **kwargs
        )  # noqa: E501

    @validate_arguments
    def delete_flow_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Delete a Flow  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_flow_with_http_info(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["flow_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_flow" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/flow/{flow_name}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_secret(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Delete a single secret k/v.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_secret(flow_name, secret_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the delete_secret_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.delete_secret_with_http_info(
            flow_name, secret_name, region, **kwargs
        )  # noqa: E501

    @validate_arguments
    def delete_secret_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Delete a single secret k/v.  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_secret_with_http_info(flow_name, secret_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["flow_name", "secret_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_secret" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        if _params["secret_name"]:
            _path_params["secret_name"] = _params["secret_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/flow/{flow_name}/secrets/{secret_name}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_flow(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> Flow:  # noqa: E501
        """Get a Flow summary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_flow(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Flow
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_flow_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_flow_with_http_info(flow_name, region, **kwargs)  # noqa: E501

    @validate_arguments
    def get_flow_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get a Flow summary  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_flow_with_http_info(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Flow, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_flow" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Flow",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_flow_status(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> Dict[str, str]:  # noqa: E501
        """Get the status of a flow's composite allocations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_flow_status(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Dict[str, str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_flow_status_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_flow_status_with_http_info(
            flow_name, region, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_flow_status_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get the status of a flow's composite allocations  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_flow_status_with_http_info(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Dict[str, str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_flow_status" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Dict[str, str]",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/status",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_secret(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> Secret:  # noqa: E501
        """Get secret details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_secret(flow_name, secret_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Secret
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_secret_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_secret_with_http_info(
            flow_name, secret_name, region, **kwargs
        )  # noqa: E501

    @validate_arguments
    def get_secret_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get secret details  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_secret_with_http_info(flow_name, secret_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Secret, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "secret_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_secret" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        if _params["secret_name"]:
            _path_params["secret_name"] = _params["secret_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Secret",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/secrets/{secret_name}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_flows(
        self,
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> List[str]:  # noqa: E501
        """Get list of all flows  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_flows(region, async_req=True)
        >>> result = thread.get()

        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the list_flows_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.list_flows_with_http_info(region, **kwargs)  # noqa: E501

    @validate_arguments
    def list_flows_with_http_info(
        self,
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get list of all flows  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_flows_with_http_info(region, async_req=True)
        >>> result = thread.get()

        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_flows" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "List[str]",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_secrets(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> Dict[str, Secret]:  # noqa: E501
        """List all secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_secrets(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Dict[str, Secret]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the list_secrets_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.list_secrets_with_http_info(
            flow_name, region, **kwargs
        )  # noqa: E501

    @validate_arguments
    def list_secrets_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """List all secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_secrets_with_http_info(flow_name, region, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Dict[str, Secret], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "region"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_secrets" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Dict[str, Secret]",
            "400": "Error",
            "401": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/secrets",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def set_secret(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        secret: Annotated[Optional[Secret], Field(description="Secret value")] = None,
        **kwargs
    ) -> Secret:  # noqa: E501
        """Set the secret value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_secret(flow_name, secret_name, region, secret, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param secret: Secret value
        :type secret: Secret
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Secret
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the set_secret_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.set_secret_with_http_info(
            flow_name, secret_name, region, secret, **kwargs
        )  # noqa: E501

    @validate_arguments
    def set_secret_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        secret_name: Annotated[
            constr(strict=True),
            Field(
                ...,
                description="Name of a secret, must be a valid shell variable name.",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        secret: Annotated[Optional[Secret], Field(description="Secret value")] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Set the secret value  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_secret_with_http_info(flow_name, secret_name, region, secret, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param secret_name: Name of a secret, must be a valid shell variable name. (required)
        :type secret_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param secret: Secret value
        :type secret: Secret
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Secret, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "secret_name", "region", "secret"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_secret" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        if _params["secret_name"]:
            _path_params["secret_name"] = _params["secret_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["secret"] is not None:
            _body_params = _params["secret"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Secret",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/secrets/{secret_name}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def set_secrets(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        request_body: Annotated[
            Optional[Dict[str, Secret]], Field(description="Flow secrets manifest")
        ] = None,
        **kwargs
    ) -> Dict[str, Secret]:  # noqa: E501
        """Set all secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_secrets(flow_name, region, request_body, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param request_body: Flow secrets manifest
        :type request_body: Dict[str, Secret]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: Dict[str, Secret]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the set_secrets_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.set_secrets_with_http_info(
            flow_name, region, request_body, **kwargs
        )  # noqa: E501

    @validate_arguments
    def set_secrets_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        region: Annotated[
            Optional[StrictStr],
            Field(description="Flow region (TBD, not spec'd for product)."),
        ] = None,
        request_body: Annotated[
            Optional[Dict[str, Secret]], Field(description="Flow secrets manifest")
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Set all secrets  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.set_secrets_with_http_info(flow_name, region, request_body, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param region: Flow region (TBD, not spec'd for product).
        :type region: str
        :param request_body: Flow secrets manifest
        :type request_body: Dict[str, Secret]
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(Dict[str, Secret], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["flow_name", "region", "request_body"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method set_secrets" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("region") is not None:  # noqa: E501
            _query_params.append(("region", _params["region"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["request_body"] is not None:
            _body_params = _params["request_body"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "Dict[str, Secret]",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/secrets",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def stream_flow_events(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        last_event_id: Annotated[
            Optional[StrictInt],
            Field(
                description="Last Event ID as described in the SSE spec, if present, resume streaming at that ID. Negative offsets count back from the end, and a 0 offset starts at the very end (tail with -n 0)."
            ),
        ] = None,
        alloc: Annotated[
            Optional[constr(strict=True)],
            Field(description="Optionally filter to a specific alloc"),
        ] = None,
        output: Annotated[
            Optional[StrictStr],
            Field(description="Filter output (e.g. stderr vs stdout)"),
        ] = None,
        **kwargs
    ) -> str:  # noqa: E501
        """(Deprecated) Stream flow events with SSE  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stream_flow_events(flow_name, last_event_id, alloc, output, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param last_event_id: Last Event ID as described in the SSE spec, if present, resume streaming at that ID. Negative offsets count back from the end, and a 0 offset starts at the very end (tail with -n 0).
        :type last_event_id: int
        :param alloc: Optionally filter to a specific alloc
        :type alloc: str
        :param output: Filter output (e.g. stderr vs stdout)
        :type output: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the stream_flow_events_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.stream_flow_events_with_http_info(
            flow_name, last_event_id, alloc, output, **kwargs
        )  # noqa: E501

    @validate_arguments
    def stream_flow_events_with_http_info(
        self,
        flow_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description="Name of a Flow. Must be less than 65 characters long. ",
            ),
        ],
        last_event_id: Annotated[
            Optional[StrictInt],
            Field(
                description="Last Event ID as described in the SSE spec, if present, resume streaming at that ID. Negative offsets count back from the end, and a 0 offset starts at the very end (tail with -n 0)."
            ),
        ] = None,
        alloc: Annotated[
            Optional[constr(strict=True)],
            Field(description="Optionally filter to a specific alloc"),
        ] = None,
        output: Annotated[
            Optional[StrictStr],
            Field(description="Filter output (e.g. stderr vs stdout)"),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """(Deprecated) Stream flow events with SSE  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.stream_flow_events_with_http_info(flow_name, last_event_id, alloc, output, async_req=True)
        >>> result = thread.get()

        :param flow_name: Name of a Flow. Must be less than 65 characters long.  (required)
        :type flow_name: str
        :param last_event_id: Last Event ID as described in the SSE spec, if present, resume streaming at that ID. Negative offsets count back from the end, and a 0 offset starts at the very end (tail with -n 0).
        :type last_event_id: int
        :param alloc: Optionally filter to a specific alloc
        :type alloc: str
        :param output: Filter output (e.g. stderr vs stdout)
        :type output: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        warnings.warn("GET /flow/{flow_name}/events is deprecated.", DeprecationWarning)

        _params = locals()

        _all_params = ["flow_name", "last_event_id", "alloc", "output"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method stream_flow_events" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["flow_name"]:
            _path_params["flow_name"] = _params["flow_name"]

        # process the query parameters
        _query_params = []
        if _params.get("alloc") is not None:  # noqa: E501
            _query_params.append(("alloc", _params["alloc"]))

        if _params.get("output") is not None:  # noqa: E501
            _query_params.append(("output", _params["output"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        if _params["last_event_id"]:
            _header_params["Last-Event-ID"] = _params["last_event_id"]

        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["text/event-stream", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "str",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/flow/{flow_name}/events",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import List
from pydantic import BaseModel, Field, StrictStr, conlist


class MetadataHeaders(BaseModel):
    """
    Specify criteria for which metadata values are added to the response as headers.
    """

    include_prefixes: conlist(StrictStr) = Field(
        ...,
        description="Provide a list of explicit metadata key prefixes to match against.",
    )
    include_patterns: conlist(StrictStr) = Field(
        ...,
        description="Provide a list of explicit metadata key regular expression (re2) patterns to match against.",
    )
    __properties = ["include_prefixes", "include_patterns"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MetadataHeaders:
        """Create an instance of MetadataHeaders from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MetadataHeaders:
        """Create an instance of MetadataHeaders from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return MetadataHeaders.parse_obj(obj)

        _obj = MetadataHeaders.parse_obj(
            {
                "include_prefixes": obj.get("include_prefixes"),
                "include_patterns": obj.get("include_patterns"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing_extensions import Annotated

from typing_extensions import Annotated
from pydantic import Field, StrictStr, constr, validator

from typing import List, Optional

from seaplane.gen.carrier.models.carrier_stream import CarrierStream
from seaplane.gen.carrier.models.carrier_stream_options import CarrierStreamOptions

from seaplane.gen.carrier.api_client import ApiClient
from seaplane.gen.carrier.api_response import ApiResponse
from seaplane.gen.carrier.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class StreamApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_stream(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        carrier_stream_options: Annotated[
            Optional[CarrierStreamOptions],
            Field(description="Stream configuration options"),
        ] = None,
        **kwargs
    ) -> None:  # noqa: E501
        """Create a new stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_stream(stream_name, carrier_stream_options, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param carrier_stream_options: Stream configuration options
        :type carrier_stream_options: CarrierStreamOptions
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the create_stream_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.create_stream_with_http_info(
            stream_name, carrier_stream_options, **kwargs
        )  # noqa: E501

    @validate_arguments
    def create_stream_with_http_info(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        carrier_stream_options: Annotated[
            Optional[CarrierStreamOptions],
            Field(description="Stream configuration options"),
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Create a new stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_stream_with_http_info(stream_name, carrier_stream_options, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param carrier_stream_options: Stream configuration options
        :type carrier_stream_options: CarrierStreamOptions
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["stream_name", "carrier_stream_options"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_stream" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["stream_name"]:
            _path_params["stream_name"] = _params["stream_name"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params["carrier_stream_options"] is not None:
            _body_params = _params["carrier_stream_options"]

        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get(
            "_content_type",
            self.api_client.select_header_content_type(["application/json"]),
        )
        if _content_types_list:
            _header_params["Content-Type"] = _content_types_list

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/stream/{stream_name}",
            "PUT",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def delete_stream(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        **kwargs
    ) -> None:  # noqa: E501
        """Delete a stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_stream(stream_name, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the delete_stream_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.delete_stream_with_http_info(stream_name, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_stream_with_http_info(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Delete a stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_stream_with_http_info(stream_name, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        _params = locals()

        _all_params = ["stream_name"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_stream" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["stream_name"]:
            _path_params["stream_name"] = _params["stream_name"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {}

        return self.api_client.call_api(
            "/stream/{stream_name}",
            "DELETE",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def get_stream(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        **kwargs
    ) -> CarrierStream:  # noqa: E501
        """Get the details of a stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_stream(stream_name, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CarrierStream
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the get_stream_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.get_stream_with_http_info(stream_name, **kwargs)  # noqa: E501

    @validate_arguments
    def get_stream_with_http_info(
        self,
        stream_name: Annotated[
            constr(strict=True, max_length=64, min_length=1),
            Field(
                ...,
                description='Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, "-" and "_". ',
            ),
        ],
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get the details of a stream  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_stream_with_http_info(stream_name, async_req=True)
        >>> result = thread.get()

        :param stream_name: Name of the stream. Must be less than 64 characters long. Allowed characters are: a-z, A-Z, 0-9, \"-\" and \"_\".  (required)
        :type stream_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CarrierStream, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["stream_name"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_stream" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params["stream_name"]:
            _path_params["stream_name"] = _params["stream_name"]

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "CarrierStream",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/stream/{stream_name}",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )

    @validate_arguments
    def list_streams(
        self,
        internal: Annotated[
            Optional[StrictStr], Field(description="List internal system streams.")
        ] = None,
        **kwargs
    ) -> List[str]:  # noqa: E501
        """Get list of all streams  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_streams(internal, async_req=True)
        >>> result = thread.get()

        :param internal: List internal system streams.
        :type internal: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: List[str]
        """
        kwargs["_return_http_data_only"] = True
        if "_preload_content" in kwargs:
            raise ValueError(
                "Error! Please call the list_streams_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"
            )
        return self.list_streams_with_http_info(internal, **kwargs)  # noqa: E501

    @validate_arguments
    def list_streams_with_http_info(
        self,
        internal: Annotated[
            Optional[StrictStr], Field(description="List internal system streams.")
        ] = None,
        **kwargs
    ) -> ApiResponse:  # noqa: E501
        """Get list of all streams  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_streams_with_http_info(internal, async_req=True)
        >>> result = thread.get()

        :param internal: List internal system streams.
        :type internal: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(List[str], status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = ["internal"]
        _all_params.extend(
            [
                "async_req",
                "_return_http_data_only",
                "_preload_content",
                "_request_timeout",
                "_request_auth",
                "_content_type",
                "_headers",
            ]
        )

        # validate the arguments
        for _key, _val in _params["kwargs"].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_streams" % _key
                )
            _params[_key] = _val
        del _params["kwargs"]

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get("internal") is not None:  # noqa: E501
            _query_params.append(("internal", _params["internal"]))

        # process the header parameters
        _header_params = dict(_params.get("_headers", {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "application/problem+json"]
        )  # noqa: E501

        # authentication setting
        _auth_settings = ["BasicAuth"]  # noqa: E501

        _response_types_map = {
            "200": "List[str]",
            "400": "Error",
            "401": "Error",
            "404": "Error",
            "503": "Error",
            "5XX": "Error",
        }

        return self.api_client.call_api(
            "/stream",
            "GET",
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get("async_req"),
            _return_http_data_only=_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=_params.get("_preload_content", True),
            _request_timeout=_params.get("_request_timeout"),
            collection_formats=_collection_formats,
            _request_auth=_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import unittest
import datetime

import seaplane.gen.carrier
from seaplane.gen.carrier.models.flow import Flow  # noqa: E501
from seaplane.gen.carrier.rest import ApiException


class TestFlow(unittest.TestCase):
    """Flow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Flow
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Flow`
        """
        model = seaplane.gen.carrier.models.flow.Flow()  # noqa: E501
        if include_optional :
            return Flow(
                input = seaplane.gen.carrier.models.input.Input(
                    carrier = seaplane.gen.carrier.models.carrier_input_config.CarrierInputConfig(
                        stream = 'example-stream', 
                        subject = 'example-stream.subject1 example-stream.subject2', 
                        queue = 'example-queue-group', 
                        durable = 'example-consumer', 
                        bind = False, 
                        deliver = 'all', 
                        ack_wait = '30s', 
                        max_ack_pending = 1024, ), 
                    http_server = seaplane.gen.carrier.models.http_server_config.HTTPServerConfig(
                        address = '', 
                        path = '/', 
                        ws_path = '/post/ws', 
                        ws_welcome_message = '', 
                        ws_rate_limit_message = '', 
                        allowed_verbs = ["POST"], 
                        timeout = '5s', 
                        rate_limit = '', 
                        cert_file = '', 
                        key_file = '', 
                        cors = seaplane.gen.carrier.models.cors.Cors(
                            enabled = False, 
                            allowed_origins = [
                                'example.com'
                                ], ), ), 
                    broker = [
                        seaplane.gen.carrier.models.broker_item.BrokerItem()
                        ], ), 
                processor = None, 
                output = seaplane.gen.carrier.models.output.Output(
                    carrier = seaplane.gen.carrier.models.carrier_output.CarrierOutput(
                        subject = 'foo', 
                        max_in_flight = 1, ), 
                    switch = seaplane.gen.carrier.models.switch.Switch(
                        cases = [
                            {"check":"this.foo < 5","output":{"carrier":{"subject":"foo.not_enough_foo","max_in_flight":1}}}
                            ], ), 
                    sync_response = seaplane.gen.carrier.models.sync_response.SyncResponse(
                        status = '200', 
                        headers = {"Content-Type":"application/octet-stream"}, 
                        metadata_headers = seaplane.gen.carrier.models.metadata_headers.MetadataHeaders(
                            include_prefixes = [
                                'foo_'
                                ], 
                            include_patterns = [
                                '.*'
                                ], ), ), 
                    drop = seaplane.gen.carrier.models.drop.Drop(), 
                    http_client = seaplane.gen.carrier.models.http_client_output.HttpClientOutput(
                        url = 'www.example.com', 
                        method = 'POST', ), 
                    azure_blob_storage = seaplane.gen.carrier.models.azure_blob_storage_output.AzureBlobStorageOutput(
                        storage_account = '', 
                        storage_access_key = '', 
                        storage_sas_token = '', 
                        storage_connection_string = '', 
                        container = 'foo', 
                        path = '${!count("files")}-${!timestamp_unix_nano()}.txt', 
                        blob_type = 'BLOCK', 
                        public_access_level = 'PRIVATE', 
                        max_in_flight = 64, ), 
                    sql_raw = seaplane.gen.carrier.models.sql_raw.SqlRaw(
                        driver = 'postgres', 
                        dsn = 'postgres://foouser:foopass@localhost:5432/foodb?sslmode=disable', 
                        query = 'INSERT INTO footable (foo, bar, baz) VALUES (?, ?, ?);', 
                        args_mapping = 'root = [ this.cat.meow, this.doc.woofs[0] ]', 
                        init_statement = 'CREATE TABLE IF NOT EXISTS some_table (
  foo varchar(50) not null,
  bar integer,
  baz varchar(50),
  primary key (foo)
) WITHOUT ROWID;
', ), ), 
                replicas = 3
            )
        else :
            return Flow(
        )
        """

    def testFlow(self):
        """Test Flow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictInt


class CarrierStreamDetails(BaseModel):
    """
    Stream details
    """

    creation_ts: Optional[StrictInt] = Field(
        None, description="Stream creation timestamp"
    )
    stored_messages: Optional[StrictInt] = Field(
        None, description="Number of all stored messages"
    )
    stored_messages_size: Optional[StrictInt] = Field(
        None, description="Size od all stored messages in bytes"
    )
    first_message_seq: Optional[StrictInt] = Field(
        None, description="Sequence number of the first message"
    )
    first_message_ts: Optional[StrictInt] = Field(
        None, description="Timestamp of the first message"
    )
    last_message_seq: Optional[StrictInt] = Field(
        None, description="Sequence number of the last message"
    )
    last_message_ts: Optional[StrictInt] = Field(
        None, description="Timestamp of the last message"
    )
    subjects: Optional[Dict[str, StrictInt]] = Field(
        None, description="Number of messages per subject"
    )
    __properties = [
        "creation_ts",
        "stored_messages",
        "stored_messages_size",
        "first_message_seq",
        "first_message_ts",
        "last_message_seq",
        "last_message_ts",
        "subjects",
    ]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CarrierStreamDetails:
        """Create an instance of CarrierStreamDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CarrierStreamDetails:
        """Create an instance of CarrierStreamDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CarrierStreamDetails.parse_obj(obj)

        _obj = CarrierStreamDetails.parse_obj(
            {
                "creation_ts": obj.get("creation_ts"),
                "stored_messages": obj.get("stored_messages"),
                "stored_messages_size": obj.get("stored_messages_size"),
                "first_message_seq": obj.get("first_message_seq"),
                "first_message_ts": obj.get("first_message_ts"),
                "last_message_seq": obj.get("last_message_seq"),
                "last_message_ts": obj.get("last_message_ts"),
                "subjects": obj.get("subjects"),
            }
        )
        return _obj



# coding: utf-8

"""
    Carrier API

    **Seaplane Global Messaging Service**  For information about authentication see [authentication](/docs/authentication)   # noqa: E501

    The version of the OpenAPI document: 1.1.0-beta
    Contact: support@seaplane.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, conint
from seaplane.gen.carrier.models.input import Input
from seaplane.gen.carrier.models.output import Output
from seaplane.gen.carrier.models.processor import Processor


class Flow(BaseModel):
    """
    defines model for Flow
    """

    input: Optional[Input] = None
    processor: Optional[Processor] = None
    output: Optional[Output] = None
    replicas: Optional[conint(strict=True, ge=0)] = Field(
        1, description="Number of task replicas"
    )
    __properties = ["input", "processor", "output", "replicas"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Flow:
        """Create an instance of Flow from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of input
        if self.input:
            _dict["input"] = self.input.to_dict()
        # override the default output from pydantic by calling `to_dict()` of processor
        if self.processor:
            _dict["processor"] = self.processor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of output
        if self.output:
            _dict["output"] = self.output.to_dict()
        # set to None if processor (nullable) is None
        # and __fields_set__ contains the field
        if self.processor is None and "processor" in self.__fields_set__:
            _dict["processor"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Flow:
        """Create an instance of Flow from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return Flow.parse_obj(obj)

        _obj = Flow.parse_obj(
            {
                "input": Input.from_dict(obj.get("input"))
                if obj.get("input") is not None
                else None,
                "processor": Processor.from_dict(obj.get("processor"))
                if obj.get("processor") is not None
                else None,
                "output": Output.from_dict(obj.get("output"))
                if obj.get("output") is not None
                else None,
                "replicas": obj.get("replicas")
                if obj.get("replicas") is not None
                else 1,
            }
        )
        return _obj
